==> v1.1.6.tar.gz: twitch-cli-1.1.6/cmd/root.go <==
// Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
// SPDX-License-Identifier: Apache-2.0
package cmd

import (
	"fmt"
	"os"

	"github.com/twitchdev/twitch-cli/internal/util"

	"github.com/spf13/cobra"

	"github.com/spf13/viper"
)

var cfgFile string

var rootCmd = &cobra.Command{
	Use:   "twitch",
	Short: "A simple CLI tool for the New Twitch API and Webhook products.",
}

// Execute adds all child commands to the root command and sets flags appropriately.
// This is called by main.main(). It only needs to happen once to the rootCmd.
func Execute() {
	if err := rootCmd.Execute(); err != nil {
		fmt.Println(err)
		os.Exit(1)
	}
}

func init() {
	cobra.OnInitialize(initConfig)

	cfgFile, err := util.GetConfigPath()
	if err != nil {
		fmt.Println(err)
		os.Exit(1)
	}

	rootCmd.PersistentFlags().StringVar(&cfgFile, "config", "", fmt.Sprintf("config file (default is %s)", cfgFile))
}

// initConfig reads in config file and ENV variables if set.
func initConfig() {
	if cfgFile != "" {
		// Use config file from the flag.
		viper.SetConfigFile(cfgFile)
	} else {
		// Find home directory.
		home, err := util.GetApplicationDir()

		if err != nil {
			fmt.Println(err)
			os.Exit(1)
		}

		// Search config in home directory with name ".twitch-cli" (without extension).
		viper.AddConfigPath(home)
		viper.SetConfigName(".twitch-cli")
		viper.SetConfigType("env")
	}

	viper.SetEnvPrefix("twitch")
	viper.AutomaticEnv() // read in environment variables that match

	// If a config file is found, read it in.
	if err := viper.ReadInConfig(); err != nil {
		return
	}
}

==> v1.1.24.tar.gz: twitch-cli-1.1.24/cmd/root.go <==
// Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
// SPDX-License-Identifier: Apache-2.0
package cmd

import (
	"fmt"
	"os"

	"github.com/twitchdev/twitch-cli/internal/util"

	"github.com/spf13/cobra"

	"github.com/spf13/viper"
)

var cfgFile string

var rootCmd = &cobra.Command{
	Use:   "twitch",
	Short: "A simple CLI tool for the New Twitch API and Webhook products.",
}

// Execute adds all child commands to the root command and sets flags appropriately.
// This is called by main.main(). It only needs to happen once to the rootCmd.
func Execute() {
	// Execute normally; Exit without checking for updates if there's an error.
	if err := rootCmd.Execute(); err != nil {
		fmt.Println(err)
		os.Exit(1)
	}

	// Check Github's Releases API to see if we're running the latest version.
	util.CheckForUpdatesAndPrintNotice()
}

func init() {
	cobra.OnInitialize(initConfig)

	var err error
	cfgFile, err = util.GetConfigPath()
	if err != nil {
		fmt.Println(err)
		os.Exit(1)
	}

	rootCmd.SilenceErrors = true
	rootCmd.SilenceUsage = true
	rootCmd.PersistentFlags().StringVar(&cfgFile, "config", "", fmt.Sprintf("config file (default is %s)", cfgFile))
}

// initConfig reads in config file and ENV variables if set.
func initConfig() {
	if cfgFile != "" {
		// Use config file from the flag.
		viper.SetConfigFile(cfgFile)
	} else {
		// Find home directory.
		home, err := util.GetApplicationDir()

		if err != nil {
			fmt.Println(err)
			os.Exit(1)
		}

		// Search config in home directory with name ".twitch-cli" (without extension).
		viper.AddConfigPath(home)
		viper.SetConfigName(".twitch-cli")
		viper.SetConfigType("env")
	}

	viper.SetEnvPrefix("twitch")
	viper.AutomaticEnv() // read in environment variables that match

	// If a config file is found, read it in.
	if err := viper.ReadInConfig(); err != nil {
		return
	}
}
